@@ -1,8 +1,7 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 # WikipediaFS
-# Copyright (C) 2005 - 2006 Mathieu Blondel
+# Copyright (C) 2005 - 2007 Mathieu Blondel
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,12 +13,13 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 import logging
 import os, os.path
+from config import CONFIG
 
 conf_dir = os.path.join(os.environ['HOME'], '.wikipediafs')
 file = os.path.join(conf_dir, 'wikipediafs.log')
@@ -28,14 +28,18 @@ file = os.path.join(conf_dir, 'wikipediafs.log')
 if not os.path.exists(conf_dir):
     os.mkdir(conf_dir,0700)
 
-logger = logging.getLogger('wikipediafs')
+LOGGER = logging.getLogger('wikipediafs')
 hdlr = logging.FileHandler(file)
 formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
 hdlr.setFormatter(formatter)
-logger.addHandler(hdlr)
-logger.setLevel(logging.INFO)
+LOGGER.addHandler(hdlr)
 
-# logger.debug('A debug message')
-# logger.info('Some information')
-# logger.warning('A shot across the bows')
-# logger.error('error...')
+if CONFIG.debug_mode:
+    LOGGER.setLevel(logging.DEBUG)
+else:
+    LOGGER.setLevel(logging.INFO)
+
+# LOGGER.debug('A debug message')
+# LOGGER.info('Some information')
+# LOGGER.warning('A shot across the bows')
+# LOGGER.error('error...')
